﻿using Prism.Mvvm;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace SASDesktop.ViewModels.Transport
{
    class Create : BindableBase
    {
        // -- VIN --
        private string _vin;
        public string VIN
        {
            get { return _vin; }
            set { _vin = value; RaisePropertyChanged(nameof(VIN)); }
        }
        
        // -- Производитель --
        // Выбранный производитель
        private Models.Brand _selectedBrand;
        public Models.Brand SelectedBrand
        {
            get { return _selectedBrand; }
            set {
                _selectedBrand = value;

                // В поле ввода производителя должно подставиться имя
                // производителя, но фильтрации происходить не должно
                _brandSearch = _selectedBrand.Name;
                RaisePropertyChanged(nameof(BrandSearch));

                // Скрываем подсказки
                BrandSuggestionsVisible = false;
            }
        }
        // Предлагаемые производители
        private List<Models.Brand> _suggestedBrands;
        public List<Models.Brand> SuggestedBrands
        {
            get { return _suggestedBrands; }
            set { _suggestedBrands = value; RaisePropertyChanged(nameof(SuggestedBrands)); }
        }
        // Поиск производителя по имени
        private string _brandSearch;
        public string BrandSearch
        {
            get => _brandSearch;
            set 
            {
                _brandSearch = value;

                // Обновление подсказок
                // Если value - пустая строка, то в список попадают все
                // сущности
                var db = new Models.SASEntities();
                SuggestedBrands = new List<Models.Brand>(
                    db.Brands.Where(b =>
                        string.IsNullOrWhiteSpace(_brandSearch) ||
                        b.Name.ToLower().Contains(_brandSearch.ToLower())
                    )
                );

                RaisePropertyChanged(nameof(BrandSearch)); 
            }
        }
        // Должны ли быть видны подсказки?
        public bool BrandSuggestionsVisible { get; set; }
        // Сфокусировано ли поле ввода в поиске?
        private bool _brandSearchFocus;
        public bool BrandSearchFocus
        {
            get => _brandSearchFocus;
            set
            {
                _brandSearchFocus = value;

                if (_brandSearchFocus == true)
                {
                    BrandSuggestionsVisible = true;
                } else
                {
                    BrandSuggestionsVisible = false;
                }
                
                RaisePropertyChanged(nameof(BrandSearchFocus));
            }
        }

        public Create() 
        {
            var db = new Models.SASEntities();
            _suggestedBrands = new List<Models.Brand>();
        }
    }
}
